Learn R Programming

stressr (version 1.0.0)

getCreditMarkets: Get credit markets stress components

Description

Downloads FRB financial stress index component data.

Usage

getCreditMarkets(s = NULL)

Arguments

s
the list of class stress from previous queries, or NULL to perform new query

Value

A list of class stress

Details

Downloads the Cleveland FRB data products for financial stress index components daily time series. Component values include
  • liquidity spread
  • covered interest spread
  • commercial paper - t-bill spread
  • treasury yield curve spread
  • coporate bond spread

See Also

getStressData getEquityMarkets getFundingMarkets getForeignExchangeMarkets getRealEstateMarkets getSecuritizationMarkets

Examples

Run this code
## Not run: 
# getCreditMarkets()
# ## End(Not run)

Run the code above in your browser using DataLab