Learn R Programming

stressr (version 1.0.0)

getEquityMarkets: Get equity markets stress components

Description

Downloads FRB financial stress index component data.

Usage

getEquityMarkets(s = NULL)

Arguments

s
the list of class stress from previous queries, or NULL to perform new query

Value

A list of class stress

Details

Downloads the Cleveland FRB data products for financial stress index components daily time series. Component values include
  • stock market crashes

See Also

getStressData getEquityMarkets getFundingMarkets getCreditMarkets getForeignExchangeMarkets getRealEstateMarkets getSecuritizationMarkets

Examples

Run this code
## Not run: 
# getEquityMarkets()
# ## End(Not run)

Run the code above in your browser using DataLab