Learn R Programming

stressr (version 1.0.0)

getFundingMarkets: Get funding markets stress components

Description

Downloads FRB financial stress index component data.

Usage

getFundingMarkets(s = NULL)

Arguments

s
the list of class stress from previous queries, or NULL to perform new query

Value

A list of class stress

Details

Downloads the Cleveland FRB data products for financial stress index components daily time series. Component values include
  • financial beta
  • interbank cost of borrowing
  • bank bond spread
  • interbank liquidity spread

See Also

getStressData getEquityMarkets getCreditMarkets getForeignExchangeMarkets getRealEstateMarkets getSecuritizationMarkets

Examples

Run this code
## Not run: 
# getFundingMarkets()
# ## End(Not run)

Run the code above in your browser using DataLab