Downloads Cleveland FRB financial stress index data.
Usage
getStressIndex(verbose = FALSE)
Arguments
verbose
whether to print progress messages, default FALSE
Value
List of class type cfsi containing xts time history object df, plot colors array colors, default plot main title main, and default plot y-axis label ylab.
Details
Transforms the HTML into a data frame, transforms the character date into Date objects, and then an xts object.