stressAreaChart: Financial stress component data as a stacked area chart.
Description
Provides a convenience function for passing a stress object to xyplot to render a sand (stacked area) chart.
Usage
stressAreaChart(e, range = NA)
Arguments
e
an object of class stress as returned by getStressComponents and its many offspring.
range
a range string as used by xts to subset time series dates, e.g. "1996/1997". Defaults to NA for full range.
Details
Provides several assumptions about the display of the stress data to correspond to similar presentations at the Cleveland Fed's data site. To implement the stacked area chart the function first computes the column-wise value accumulations, then passes these values to the latticeExtraxyarea polygon rendering tools. Plots the columns in reverse stacking order to show the desired overlaps.