Learn R Programming

stressr (version 1.0.0)

stressIndexChart: Financial stress index data line chart with regions.

Description

Provides a convenience function for passing a cfsi object to xyplot with attributes as presented by the source.

Usage

stressIndexChart(e, range = NA, showGradeRegions = TRUE)

Arguments

e
an object of class cfsi as returned by getStressIndex.
range
a range string as used by xts to subset time series dates, e.g. "1996/1997". Defaults to NA for full range.
showGradeRegions
whether to show the stress grade regions and labels

Details

Provides several assumptions about the display of the cfsi data to correspond to similar presentations at the Cleveland Fed's data site.

See Also

xyplot.cfsi getStressIndex

Examples

Run this code
## Not run: 
# idx <- getStressIndex()
# stressIndexChart(idx)
# ## End(Not run)

Run the code above in your browser using DataLab