Learn R Programming

stressr (version 1.0.0)

stressr: Financial stress index component data.

Description

Fetches financial stress index component data as time series and provides plots.

Arguments

Details

Downloads the financial stress index component daily data in its original XLS format from the Federal Reserve Bank of Cleveland's web site, and then translates that data into an xts time series object with stress component value histories as columns. Provides custom lattice line and area plot functions for data presentation.

References

Federal Reserve Bank of Cleveland research data site http://www.clevelandfed.org/research/data/financial_stress_index/index.cfm